@@ -12,11 +12,11 @@ class ItemMemStore(ItemStore):
         self.types = types
         self.items = items
 
-    def create_type(self, name, items=None, data=None, attributes=None):
+    def create_type(self, name, items=None, data=None, attributes={}):
         references = []
         if items:
             references = [existing for existing in [self.items.get(item.id) for item in items] if existing]
-        id = uuid.uuid4()
+        id = str(uuid.uuid4())
         new = Type(id, name, references, attributes)
         self.types[id] = new
         return new
@@ -43,7 +43,7 @@ class ItemMemStore(ItemStore):
         if type is None:
             return None
 
-        id = uuid.uuid4()
+        id = str(uuid.uuid4())
         new = Item(id, name if name else type.name, type, attributes)
         self.items[id] = new
 
@@ -68,7 +68,7 @@ class ItemMemStore(ItemStore):
 
     def save(self, path):
         with open(path, 'w') as outfile:
-            json.dump({'types': self.types, 'items': self.items}, outfile)
+            json.dump({'types': [t.to_dict() for t in self.types], 'items': [i.to_dict() for i in self.items]}, outfile)
 
     @classmethod
     def load(cls, path):
